/*
* Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
* ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
*/

/*
 * $Id: LocalTransactionImpl.java 67292 2012-08-23 20:45:07Z phendley $
 */

package com.sun.ts.tests.common.connector.whitebox;

import javax.resource.ResourceException;
import javax.resource.spi.*;
import com.sun.ts.tests.common.connector.util.*;

public class LocalTransactionImpl implements LocalTransaction {


    private TSManagedConnection mc;

    /* @name     LocalTransactionImpl
     * @desc     LocalTransactionImpl constructor
     * @param    TSManagedConnection
     */
    public LocalTransactionImpl(TSManagedConnection mc) {
        this.mc = mc;
    }

     /* @name     begin
     * @desc     sends the event that local transaction has started
     * @exception ResourceException
     * 
     */
    @Override
    public void begin() throws ResourceException {
        try {
            TSConnection con = mc.getTSConnection();
	    ConnectorStatus.getConnectorStatus().logAPI("LocalTransaction.begin", "","");
	    con.setAutoCommit(false);
	    System.out.println("LocalTransaction.begin");
        } catch (Exception ex) {
            ResourceException re = new EISSystemException(ex.getMessage());
            re.initCause(ex);
            throw re;
        }
    }


    /* @name     commit
     * @desc     Sends an event that local transaction has been commited.
     * @exception ResourceException
     */
    @Override
    public void commit() throws ResourceException {
        TSConnection con = null;
        try {
            con = mc.getTSConnection();
	    ConnectorStatus.getConnectorStatus().logAPI("LocalTransaction.commit", "","");
	    System.out.println("LocalTransaction.commit");
            con.commit();
        } catch (Exception ex) {
            ResourceException re = new EISSystemException(ex.getMessage());
            re.initCause(ex);
            throw re;
 	}  finally {
            try {
            	if (con != null) {
                    con.setAutoCommit(true);
            	}
            } catch (Exception ex) {
		ex.getMessage();
		}
	}
    }
     


    /* @name     rollback
     * @desc     Sends an event to rollback the transaction
     * @exception ResourceException
     */
    @Override
    public void rollback() throws ResourceException {
        TSConnection con = null;
        try {
            con = mc.getTSConnection();
	    ConnectorStatus.getConnectorStatus().logAPI("LocalTransaction.rollback", "","");
            con.rollback();
        } catch (Exception ex) {
            ResourceException re = new EISSystemException(ex.getMessage());
            re.initCause(ex);
            throw re;
        } finally {
            try {
            	if (con != null) {
                    con.setAutoCommit(true);
            	}
            } catch (Exception ex) {}
        }
    }
}
